0.1.19 (2019-04-24)
-------------------

* Added fulltext search
* Added filtering by date + some faceted navigation support
* use overwritable template block for feeds section (could be used for podlove subscribe button)
